==> modules_weight-8.x-1.0.tar.gz: modules_weight/src/Form/ModulesListForm.php <==
<?php

namespace Drupal\modules_weight\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;

/**
 * Builds the form to configure the Modules weight.
 */
class ModulesListForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'modules_weight_modules_list';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // The table header.
    $header = [
      $this->t('Name'),
      $this->t('Description'),
      [
        'data' => $this->t('Weight'),
        'colspan' => 2,
      ],
      $this->t('Package'),
    ];

    // The table.
    $form['modules'] = [
      '#type' => 'table',
      '#header' => $header,
      '#sticky' => TRUE,
    ];

    // Getting the module list.
    $modules = system_rebuild_module_data();
    // Sorting all modules by their weight.
    uasort($modules, '_modules_weight_sort_modules_by_weight');

    // Getting the config to know of we should show or not the core modules.
    $show_system_modules = \Drupal::config('modules_weight.settings')->get('show_system_modules');

    // Iterate over each of the modules.
    foreach ($modules as $filename => $module) {
      if (empty($module->info['hidden']) && $module->status && ($show_system_modules || $module->info['package'] != 'Core')) {

        $compatible = TRUE;

        // Check the core compatibility.
        if ($module->info['core'] != \Drupal::CORE_COMPATIBILITY) {
          $compatible = FALSE;
        }

        // This module is compatible with the currently installed PHP version?
        if (version_compare(phpversion(), $module->info['php']) < 0) {
          $compatible = FALSE;
        }

        // If this module is not compatible it will not be show.
        if (!$compatible) {
          continue;
        }

        // The rows info.
        // Module name.
        $form['modules'][$filename]['name'] = [
          '#markup' => $module->info['name'],
        ];
        // Module description.
        $form['modules'][$filename]['description'] = [
          '#markup' => $module->info['description'],
        ];
        // Module weight.
        $form['modules'][$filename]['weight'] = [
          '#type' => 'weight',
          '#default_value' => $module->weight,
          '#delta' => modules_weight_prepare_delta($module->weight),
        ];
        // Module old weight value, used to see if we need to update the weight.
        $form['modules'][$filename]['old_weight_value'] = [
          '#type' => 'hidden',
          '#value' => $module->weight,
        ];
        // Module package.
        $form['modules'][$filename]['package'] = [
          '#markup' => $module->info['package'],
        ];
      }
    }
    // The form button.
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => t('Save Changes'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Variable to see if we have uptaded some module weight.
    $update = FALSE;
    // The modules information.
    $modules_info = $form_state->getValue('modules');

    foreach ($modules_info as $module => $values) {
      // Checking if a value has changed.
      if ($modules_info[$module]['weight'] != $modules_info[$module]['old_weight_value']) {
        // Setting the new weight.
        module_set_weight($module, $values['weight']);
        $update = TRUE;
      }
      // Printing the update message.
      if ($update) {
        drupal_set_message($this->t('The modules weight was updated.'));
      }
    }
  }

}

==> modules_weight-8.x-1.1.tar.gz: modules_weight/src/Form/ModulesListForm.php <==
<?php

namespace Drupal\modules_weight\Form;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Form\FormBase;

/**
 * Builds the form to configure the Modules weight.
 */
class ModulesListForm extends FormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'modules_weight_modules_list';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    // The table header.
    $header = [
      $this->t('Name'),
      $this->t('Description'),
      [
        'data' => $this->t('Weight'),
        'colspan' => 2,
      ],
      $this->t('Package'),
    ];

    // The table.
    $form['modules'] = [
      '#type' => 'table',
      '#header' => $header,
      '#sticky' => TRUE,
    ];

    // Getting the module list.
    $modules = _modules_weight_modules_list();
    // Iterate over each of the modules.
    foreach ($modules as $filename => $module) {
      // The rows info.
      // Module name.
      $form['modules'][$filename]['name'] = [
        '#markup' => $module->info['name'],
      ];
      // Module description.
      $form['modules'][$filename]['description'] = [
        '#markup' => $module->info['description'],
      ];
      // Module weight.
      $form['modules'][$filename]['weight'] = [
        '#type' => 'weight',
        '#default_value' => $module->weight,
        '#delta' => _modules_weight_prepare_delta($module->weight),
      ];
      // Module old weight value, used to see if we need to update the weight.
      $form['modules'][$filename]['old_weight_value'] = [
        '#type' => 'hidden',
        '#value' => $module->weight,
      ];
      // Module package.
      $form['modules'][$filename]['package'] = [
        '#markup' => $module->info['package'],
      ];
    }
    // The form button.
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => t('Save Changes'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    // Variable to see if we have uptaded some module weight.
    $update = FALSE;
    // The modules information.
    $modules_info = $form_state->getValue('modules');

    foreach ($modules_info as $module => $values) {
      // Checking if a value has changed.
      if ($modules_info[$module]['weight'] != $modules_info[$module]['old_weight_value']) {
        // Setting the new weight.
        module_set_weight($module, $values['weight']);
        $update = TRUE;
      }
      // Printing the update message.
      if ($update) {
        drupal_set_message($this->t('The modules weight was updated.'));
      }
    }
  }

}
